==> libdatetime-locale-perl_1.16.orig.tar.gz: DateTime-Locale-1.16/share/nb-NO.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m."
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L.",
    MEd => "E d.M",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "W. 'uke' 'i' MMM",
    "MMMMW-count-other" => "W. 'uke' 'i' MMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d.M.",
    Md => "d.M.",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.MM.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'uke' w 'i' y",
    "yw-count-other" => "'uke' w 'i' y"
  },
  code => "nb-NO",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n."
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S"
  ],
  day_format_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag"
  ],
  day_stand_alone_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n."
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S"
  ],
  day_stand_alone_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag"
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr."
  ],
  era_narrow => [
    "f.Kr.",
    "e.Kr."
  ],
  era_wide => [
    "f\N{U+00f8}r Kristus",
    "etter Kristus"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d. %b %H:%M:%S %z %Y",
  glibc_date_format => "%d. %b %Y",
  glibc_datetime_format => "%a %d. %b %Y kl. %H.%M %z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "kl. %H.%M %z",
  language => "Norwegian Bokm\N{U+00e5}l",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des."
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember"
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember"
  ],
  name => "Norwegian Bokm\N{U+00e5}l Norway",
  native_language => "norsk bokm\N{U+00e5}l",
  native_name => "norsk bokm\N{U+00e5}l Norge",
  native_script => undef,
  native_territory => "Norge",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4."
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal"
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4."
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal"
  ],
  script => undef,
  territory => "Norway",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> libdatetime-locale-perl_1.24.orig.tar.gz: DateTime-Locale-1.24/share/nb-NO.pl <==
{
  am_pm_abbreviated => [
    "a.m.",
    "p.m.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L.",
    MEd => "E d.M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "W. 'uke' 'i' MMMM",
    "MMMMW-count-other" => "W. 'uke' 'i' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMdd => "d.M.",
    Md => "d.M.",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E d.MM.y",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'uke' w 'i' Y",
    "yw-count-other" => "'uke' w 'i' Y",
  },
  code => "nb-NO",
  date_format_full => "EEEE d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  day_stand_alone_abbreviated => [
    "man.",
    "tir.",
    "ons.",
    "tor.",
    "fre.",
    "l\N{U+00f8}r.",
    "s\N{U+00f8}n.",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "mandag",
    "tirsdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f8}rdag",
    "s\N{U+00f8}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_wide => [
    "f\N{U+00f8}r Kristus",
    "etter Kristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d. %b %H:%M:%S %z %Y",
  glibc_date_format => "%d. %b %Y",
  glibc_datetime_format => "%a %d. %b %Y kl. %H.%M %z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "kl. %H.%M %z",
  language => "Norwegian Bokm\N{U+00e5}l",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "april",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  name => "Norwegian Bokm\N{U+00e5}l Norway",
  native_language => "norsk bokm\N{U+00e5}l",
  native_name => "norsk bokm\N{U+00e5}l Norge",
  native_script => undef,
  native_territory => "Norge",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_format_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    "1.",
    "2.",
    "3.",
    "4.",
  ],
  quarter_stand_alone_wide => [
    "1. kvartal",
    "2. kvartal",
    "3. kvartal",
    "4. kvartal",
  ],
  script => undef,
  territory => "Norway",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
